function z = NewAndrzejakChaos2020Maps(N,c,CwDivN,CaDivN,initialconditions,maxiter, plotrange)

% This source code allows you to reproduce the simulations presented in 
%
% Andrzejak RG, Ruzzene G, Schll E, Omelchenko I. 
% Two populations of coupled quadratic maps exhibit a plentitude of symmetric 
% and symmetry broken dynamics. 
% Chaos. 2020, 30 (3), 033125. DOI: 10.1063/5.0002272
%
% Please give a reference to this manuscript if you use this source code in
% your publications.
%
% Input parameters:
% N: 
% Number of maps in each of the two populations.(Same notation as in manuscript)
%
% CwDivN: 
% Coupling within both populations divided by N. (Same notation as in manuscript)
% ATTENTION. This is indeed the coupling already divided by the number of
% oscillators (which is done for computational efficiency).
%
% CaDivN: 
% Coupling across both populations divided by N. (Same notation as in manuscript)
% ATTENTION. This is indeed the coupling already divided by the number of
% oscillators (which is done for computational efficiency).
%
% maxiter:
% Total number of iterations. Corresponds to the maximum of discrete time t
% in the manuscript.
%
% initialconditions
% intial conditions of the maps at time t=1. 
% Expected as vector of (2*N,1). The values 1:N are used for the first
% population and N+1:2*N are used for the second population.
% 
% plotrange:
% Range of discrete time for which the solution is plotted. If left empty
% no plot will be made.
% 
% OUTPUT
% z: 
% values of maps in a matrix of size (2*N,maxiter). Accordingly, the first
% degree of freedom corresponds to the map index, where again 1:N are used 
% for the first population and N+1:2*N are used for the second population.
% The second degree of freedom corresponds to discrete time.



% Allocate space for iterates and write initial conditions to first iterate
Ntotal = 2*N;
yrange = 1:N;
xrange = N+1:2*N;
% Note that populations x and y correspond to population 2 and 1,
% respectively. This naming convention is arbitrary since they are
% identical
z=ones(Ntotal,maxiter);
z(:,1)=initialconditions;
% Define connectity matrix corresponding to two populations
G = ones(Ntotal,Ntotal)*CaDivN;
G(yrange,yrange)=CwDivN;
G(xrange,xrange)=CwDivN;

% Carry out the actual iterations
for counter1 = 2:maxiter;
    m1 = z(:,counter1-1).^2+c;
    z(:,counter1)=m1+sum(bsxfun(@minus,m1.',m1).*G,2);
end

% Create simple examplary plots of the result.
if ~isempty(plotrange)    
    figure;
    subplot(211);
    imagesc(plotrange,xrange, z(xrange,plotrange),[-1.8, 1.35]);
    xlabel('iteration');
    ylabel('map index x');
    subplot(212);
    imagesc(plotrange,yrange, z(yrange,plotrange),[-1.8, 1.35]);
    xlabel('iteration');
    ylabel('map index y');
    
    disp('Waring: If you have less pixels than time and/or map indices, you will see aliasing');
    colormap(gray);
end






